@@ -1,4 +1,4 @@
 # from .api.four_chan import *
 # from .schemas.four_chan import *
 
-__all__ = ['schemas', 'api', 'db']
+__all__ = ['schemas', 'api', 'db', 'settings']
